%define major      1
%define libname    %mklibname %name %major
%define libnamedev %mklibname %name -d

Summary:        Text to speech synthesis engine
Name:           espeak
Version:        1.48.04
Release:        %mkrel 6
License:        GPLv3+
Group:          Sound/Utilities
Url:            https://espeak.sourceforge.net/
Source0:        https://downloads.sourceforge.net/%{name}/%{name}-%{version}-source.zip
Source1:        espeak.1
Patch0:         espeak-1.48.04-fix.patch
BuildRequires:  portaudio-devel
Requires:       sox

%description
eSpeak is a compact open source software speech synthesizer for
English and other languages.

eSpeak produces good quality English speech. It uses a different
synthesis method from other open source TTS engines, and sounds quite
different. It's perhaps not as natural or "smooth", but I find the
articulation clearer and easier to listen to for long periods.


%package -n     %libname
Group:          System/Libraries
Summary:        Text to speech library
Requires:       %name >= %version

%description -n %libname
eSpeak is a compact open source software speech synthesizer for
English and other languages.

eSpeak produces good quality English speech. It uses a different
synthesis method from other open source TTS engines, and sounds quite
different. It's perhaps not as natural or "smooth", but I find the
articulation clearer and easier to listen to for long periods.


%package -n     %libnamedev
Group:          Development/C++
Summary:        Text to speech library
Requires:       %libname = %version
Provides:       libespeak-devel = %version-%release

%description -n %libnamedev
eSpeak is a compact open source software speech synthesizer for
English and other languages.

eSpeak produces good quality English speech. It uses a different
synthesis method from other open source TTS engines, and sounds quite
different. It's perhaps not as natural or "smooth", but I find the
articulation clearer and easier to listen to for long periods.


%prep
%setup -q -n %name-%version-source
%patch -P 0 -p0

chmod 644 ReadMe *.txt
rm -f src/portaudio.h
rm -f src/portaudio18.h
rm -f src/portaudio19.h

# (Fedora) Don't use the included binary voice dictionaries; we compile these from source
rm -f espeak-data/*_dict

%build
cd src
%__make CXXFLAGS="%{optflags}" LDFLAGS="%{?ldflags}"

# (Fedora) Compile the TTS voice dictionaries
export ESPEAK_DATA_PATH=%{_builddir}/espeak-%{version}-source
cd ../dictsource
for voice in $(../src/speak --voices | awk '{print $2}{print $5}' | egrep -v Language\|File\|/ | uniq);
do ../src/speak --compile=$voice;
done

%install
cd src
%make_install BINDIR=%_bindir INCDIR=%_includedir/%name LIBDIR=%_libdir DATADIR=%_datadir/%name-data

install -m 644 -D %SOURCE1 %buildroot%_mandir/man1/%name.1

# don't ship .a
rm -f %buildroot%_libdir/libespeak.a

%pretrans -p <lua>
-- # (cg) espeak 1.47.11 changed a previous versions folder to a file causing cpio
-- # errors on upgrade - this will still cause problems
-- # (ngompa) Converted to Lua
-- # See: https://fedoraproject.org/wiki/User:Patches/PackagingDrafts/Symlink_Workarounds
path = "/usr/share/espeak-data/voices/en"
st = posix.stat(path)
if st and st.type == "directory" then
  os.execute("rm -rf " .. path)
end

%files
%doc ReadMe *.txt docs
%_bindir/%name
%_datadir/%name-data
%_mandir/man1/%name.1*

%files -n %libname
%_libdir/libespeak.so.%{major}{,.*}

%files -n %libnamedev
%_includedir/%name
%_libdir/libespeak.so


%changelog
* Sat Dec 21 2024 pterjan <pterjan> 1.48.04-6.mga10
+ Revision: 2127279
- Rebuild for patchN deprecation

* Fri Apr 01 2022 umeabot <umeabot> 1.48.04-5.mga9
+ Revision: 1838765
- Mageia 9 Mass Rebuild

* Thu Feb 13 2020 umeabot <umeabot> 1.48.04-4.mga8
+ Revision: 1512096
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.48.04-3.mga7
+ Revision: 1297625
- Mageia 7 Mass Rebuild

* Thu Oct 26 2017 zezinho <zezinho> 1.48.04-2.mga7
+ Revision: 1173849
- remove old portaudio headers - fix build with a patch
- try to fix build
- new version

* Sat Dec 10 2016 ngompa <ngompa> 1.47.11-7.mga6
+ Revision: 1074063
- Convert %%pretrans to Lua

* Tue Feb 02 2016 umeabot <umeabot> 1.47.11-6.mga6
+ Revision: 932584
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.47.11-5.mga5
+ Revision: 749107
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.47.11-4.mga5
+ Revision: 679030
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.47.11-3.mga4
+ Revision: 528345
- Mageia 4 Mass Rebuild

* Tue Jun 18 2013 colin <colin> 1.47.11-2.mga4
+ Revision: 444620
- Add a pretrans to make upgrades work

* Mon Jun 17 2013 dlucio <dlucio> 1.47.11-1.mga4
+ Revision: 444140
- 1.47.11

* Fri Jan 11 2013 umeabot <umeabot> 1.46.02-3.mga3
+ Revision: 349734
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 29 2012 malo <malo> 1.46.02-2.mga3
+ Revision: 322795
- update RPM group

* Sat Jan 28 2012 kamil <kamil> 1.46.02-1.mga2
+ Revision: 202610
- new version 1.46.02

* Sun Dec 11 2011 fwang <fwang> 1.46.01-1.mga2
+ Revision: 180718
- new version 1.46.01

* Fri Sep 23 2011 doktor5000 <doktor5000> 1.45.05-1.mga2
+ Revision: 147074
- dropped ldflags patch, not needed anymore
- dropped pulseaudio-runtime-detection patch, not needed anymore

* Thu Jan 20 2011 ahmad <ahmad> 1.43.03-2.mga1
+ Revision: 25800
- don't use the included binary voice dictionaries; compile them from source instead
  (from Fedora)
- drop old/unneeded scriptlets
- don't ship .a
- imported package espeak

